@@ -1,7 +1,7 @@
 """
 widgets for django-form-utils
 
-Time-stamp: <2009-11-25 02:54:50 carljm widgets.py>
+Time-stamp: <2010-03-05 15:03:36 carljm widgets.py>
 
 parts of this code taken from http://www.djangosnippets.org/snippets/934/
  - thanks baumer1122
@@ -10,14 +10,14 @@ parts of this code taken from http://www.djangosnippets.org/snippets/934/
 import os
 import posixpath
 
-from PIL import Image
-
 from django import forms
 from django.conf import settings
 from django.utils.functional import curry
 from django.utils.safestring import mark_safe
 from django.core.files.uploadedfile import SimpleUploadedFile as UploadedFile
 
+from form_utils.settings import JQUERY_URL, FORM_UTILS_MEDIA_URL
+
 try:
     from sorl.thumbnail.main import DjangoThumbnail
     def thumbnail(image_path):
@@ -37,6 +37,7 @@ class ImageWidget(forms.FileInput):
         super(ImageWidget, self).__init__(attrs)
     
     def render(self, name, value, attrs=None):
+        from PIL import Image
         input_html = super(forms.FileInput, self).render(name, value, attrs)
         file_name = str(value)
         file_path = os.path.join(settings.MEDIA_ROOT, file_name)
@@ -72,3 +73,38 @@ class ClearableFileInput(forms.MultiWidget):
             return self.template % {'input': rendered_widgets[0],
                                     'checkbox': rendered_widgets[1]}
         return rendered_widgets[0]
+
+root = lambda path: posixpath.join(FORM_UTILS_MEDIA_URL, path)
+    
+class AutoResizeTextarea(forms.Textarea):
+    """
+    A Textarea widget that automatically resizes to accomodate its contents.
+    
+    """
+    class Media:
+        
+        js = (JQUERY_URL,
+              root('form_utils/js/jquery.autogrow.js'),
+              root('form_utils/js/autoresize.js'))
+
+    def __init__(self, *args, **kwargs):
+        attrs = kwargs.setdefault('attrs', {})
+        try:
+            attrs['class'] = "%s autoresize" % (attrs['class'],)
+        except KeyError:
+            attrs['class'] = 'autoresize'
+        attrs.setdefault('cols', 80)
+        attrs.setdefault('rows', 5)
+        super(AutoResizeTextarea, self).__init__(*args, **kwargs)
+
+class InlineAutoResizeTextarea(AutoResizeTextarea):
+    def __init__(self, *args, **kwargs):
+        attrs = kwargs.setdefault('attrs', {})
+        try:
+            attrs['class'] = "%s inline" % (attrs['class'],)
+        except KeyError:
+            attrs['class'] = 'inline'
+        attrs.setdefault('cols', 40)
+        attrs.setdefault('rows', 2)
+        super(InlineAutoResizeTextarea, self).__init__(*args, **kwargs)
+
